summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--xmake/modules/private/action/require/impl/package.lua6
1 files changed, 5 insertions, 1 deletions
diff --git a/xmake/modules/private/action/require/impl/package.lua b/xmake/modules/private/action/require/impl/package.lua
index 04557715c..689f9805c 100644
--- a/xmake/modules/private/action/require/impl/package.lua
+++ b/xmake/modules/private/action/require/impl/package.lua
@@ -675,10 +675,14 @@ end
-- select to use precompiled artifacts?
function _select_artifacts(package, artifacts_manifest)
- -- the precompile policy is disabled?
+ -- the precompile policy is disabled in package?
if package:policy("package.precompiled") == false then
return
end
+ -- the precompile policy is disabled in project?
+ if os.isfile(os.projectfile()) and project.policy("package.precompiled") == false then
+ return
+ end
local artifacts_info
if package:is_plat("windows") then -- for msvc
artifacts_info = _select_artifacts_for_msvc(package, artifacts_manifest)